#!/bin/bash
#
#   USAGE:  buildSqlite.sh <debug|opt|prof> [tar] [source]
#   NOTE:  we build sqlite with the native compiler

usage()
{
    echo "USAGE: buildSqlite.sh <debug|opt|prof> [tar]"
}

make_tarball()
{
    echo ""
    echo "OK - building tarball for ${package} ${pkgver} ${flvr} ${qual}"
    set -x
    cd ${PRODUCTS}
    tarname=${package}-${pkgdotver}-${OS}-${plat}-${qualdir}.tar.bz2
    tar cjf ${tarname} \
       ${package}/${pkgver}.version/${flvr}_${qualver} \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source \
       ${package}/${pkgver}/${flvr}-${qualdir}
    cd ${thisdir}
    set +x
    exit 0
}

make_source_tarball()
{
    set -x
    cd ${PRODUCTS}
    tar cjf ${package}-${pkgdotver}-source.tar.bz2 \
       ${package}/${pkgver}/*.sh \
       ${package}/${pkgver}/ups \
       ${package}/${pkgver}/source
    cd ${thisdir}
    set +x
}

extraqual=${1}
maketar=${2}
sourcetar=${3}

package=sqlite
pkgver=v3_07_16_00
pkgbasever=`echo ${pkgver} | sed -e 's/_//g' | sed -e 's/^v//'`
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
thisdir=`pwd`

if [ -z ${PRODUCTS} ]
then
    echo "ERROR: ups is not setup"
    exit 1
fi

if [ "${sourcetar}" = "source" ]
then
  make_source_tarball
fi

if [ "${extraqual}" = "debug" ]
then
    cxxflg="-g -O0"
elif [ "${extraqual}" = "opt" ]
then
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "prof" ]
then
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
    echo "ERROR: please specify debug, opt, or prof"
    usage
    exit 1
fi
qual=${extraqual}
qualdir=${extraqual}
qualver=${extraqual}

source ${PRODUCTS}/setup

OS1=`uname`
if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    #OS=${OS1}${OSnum}
    mactype=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | wc -w`
    if [ ${mactype} -gt 0 ]
    then
       macos=`system_profiler  -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
       macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
       macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    else 
       macos=`system_profiler  -xml -detailLevel mini SPSoftwareDataType | grep "OS X" | cut -d ' ' -f 3 | cut -d . -f 1,2`
       macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep "OS X" | cut -d ' ' -f 3 | cut -d . -f 1`
       macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep "OS X" | cut -d ' ' -f 3 | cut -d . -f 2`
    fi
    OS=osx${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
   if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
   then
      OS=slf${OSnum}
   fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

pkgdir=${PRODUCTS}/${package}/${pkgver}/${flvr}-${qualdir}
sourcedir=${PRODUCTS}/sqlite/${pkgver}/source/${package}-autoconf-${pkgbasever}

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi

set -x

cd ${pkgdir}/build

CFLAGS="${cxxflg}" ${sourcedir}/configure --prefix=${pkgdir}
make 
make check
make install 

set +x


if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi


# this should not complain
echo "Declaring ${package} ${pkgver} for ${flvr} and ${qualver}"
if [ ${OS1} = "Darwin" ]
then
   ups declare ${package} ${pkgver} -r ${package}/${pkgver} -2 -m ${package}.table -q ${qualver}
else 
   ups declare ${package} ${pkgver} -r ${package}/${pkgver} -4 -m ${package}.table -q ${qualver}
fi
setup ${package} ${pkgver} -q ${qualver}
echo "${package} is installed at ${SQLITE_FQ_DIR}"

# fixing embedded path
mv ${SQLITE_FQ_DIR}/lib/pkgconfig/sqlite3.pc ${SQLITE_FQ_DIR}/lib/pkgconfig/sqlite3.pc.bak
cat ${SQLITE_FQ_DIR}/lib/pkgconfig/sqlite3.pc.bak | sed 's%^prefix=.*$%prefix=${SQLITE_FQ_DIR}%' > ${SQLITE_FQ_DIR}/lib/pkgconfig/sqlite3.pc

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   make_tarball
fi

exit 0
